summaryrefslogtreecommitdiff
path: root/IkiWiki/Plugin
diff options
context:
space:
mode:
authorJoey Hess <joey@kodama.kitenet.net>2008-08-25 13:38:44 -0400
committerJoey Hess <joey@kodama.kitenet.net>2008-08-25 13:38:44 -0400
commit4956623ee6b95c9fc62d8af39d9236ddeb6de8c5 (patch)
tree1e6ace9da32236c446154a3e630735ef314ed738 /IkiWiki/Plugin
parentc62cbc31c2b7db7694c341ddb4212545728cb3b7 (diff)
rename plugin
I don't want to be stuck renameing it later if preprocessor directives are turned into postprocessor directives. Also, "directives" is shorter and clearer than "preprocessors".
Diffstat (limited to 'IkiWiki/Plugin')
-rw-r--r--IkiWiki/Plugin/listdirectives.pm (renamed from IkiWiki/Plugin/listpreprocessors.pm)38
1 files changed, 19 insertions, 19 deletions
diff --git a/IkiWiki/Plugin/listpreprocessors.pm b/IkiWiki/Plugin/listdirectives.pm
index ca58ef1a1..fe4aee3bb 100644
--- a/IkiWiki/Plugin/listpreprocessors.pm
+++ b/IkiWiki/Plugin/listdirectives.pm
@@ -1,16 +1,16 @@
#!/usr/bin/perl
-# Ikiwiki listpreprocessors plugin.
-package IkiWiki::Plugin::listpreprocessors;
+# Ikiwiki listdirectives plugin.
+package IkiWiki::Plugin::listdirectives;
use warnings;
use strict;
use IkiWiki 2.00;
sub import { #{{{
- hook(type => "getsetup", id => "listpreprocessors", call => \&getsetup);
- hook(type => "checkconfig", id => "listpreprocessors", call => \&checkconfig);
- hook(type => "needsbuild", id => "listpreprocessors", call => \&needsbuild);
- hook(type => "preprocess", id => "listpreprocessors", call => \&preprocess);
+ hook(type => "getsetup", id => "listdirectives", call => \&getsetup);
+ hook(type => "checkconfig", id => "listdirectives", call => \&checkconfig);
+ hook(type => "needsbuild", id => "listdirectives", call => \&needsbuild);
+ hook(type => "preprocess", id => "listdirectives", call => \&preprocess);
} # }}}
sub getsetup () { #{{{
@@ -19,9 +19,9 @@ sub getsetup () { #{{{
safe => 1,
rebuild => undef,
},
- preprocessor_description_dir => {
+ directive_description_dir => {
type => "string",
- description => "directory in srcdir that contains preprocessor descriptions",
+ description => "directory in srcdir that contains PreprocessorDirective descriptions",
example => "ikiwiki/plugin",
safe => 1,
rebuild => 1,
@@ -33,11 +33,11 @@ my @earlylist;
my $pluginstring;
sub checkconfig () { #{{{
- if (! defined $config{preprocessor_description_dir}) {
- $config{preprocessor_description_dir} = "ikiwiki/plugin";
+ if (! defined $config{directive_description_dir}) {
+ $config{directive_description_dir} = "ikiwiki/plugin";
}
else {
- $config{preprocessor_description_dir}=~s/\/+$//;
+ $config{directive_description_dir}=~s/\/+$//;
}
@earlylist = sort( keys %{ $IkiWiki::hooks{preprocess} } );
@@ -50,16 +50,16 @@ sub needsbuild (@) { #{{{
$pluginstring = join (' ', @earlylist) . " : ". join (' ', @fulllist);
foreach my $page (keys %pagestate) {
- if (exists $pagestate{$page}{listpreprocessors}{shown}) {
- if ($pagestate{$page}{listpreprocessors}{shown} ne $pluginstring) {
+ if (exists $pagestate{$page}{listdirectives}{shown}) {
+ if ($pagestate{$page}{listdirectives}{shown} ne $pluginstring) {
push @$needsbuild, $pagesources{$page};
}
if (exists $pagesources{$page} &&
grep { $_ eq $pagesources{$page} } @$needsbuild) {
# remove state, will be re-added if
# the [[!listpreprocessors]] is still there during the
# rebuild
- delete $pagestate{$page}{listpreprocessors}{shown};
+ delete $pagestate{$page}{listdirectives}{shown};
}
}
}
@@ -68,7 +68,7 @@ sub needsbuild (@) { #{{{
sub preprocess (@) { #{{{
my %params=@_;
- $pagestate{$params{destpage}}{listpreprocessors}{shown}=$pluginstring;
+ $pagestate{$params{destpage}}{listdirectives}{shown}=$pluginstring;
my @pluginlist;
@@ -79,12 +79,12 @@ sub preprocess (@) { #{{{
@pluginlist = @earlylist;
}
- my $result = '<ul class="listpreprocessors">';
+ my $result = '<ul class="listdirectives">';
foreach my $plugin (@pluginlist) {
- $result .= '<li class="listpreprocessors">';
+ $result .= '<li class="listdirectives">';
$result .= htmllink($params{page}, $params{destpage},
- IkiWiki::linkpage($config{preprocessor_description_dir}."/".$plugin));
+ IkiWiki::linkpage($config{directive_description_dir}."/".$plugin));
$result .= '</li>';
}
@@ -50,16 +50,16 @@ sub needsbuild (@) { #{{{
grep { $_ eq $pagesources{$page} } @$needsbuild) {
# remove state, will be re-added if
- # the [[!listpreprocessors]] is still there during the
+ # the [[!listdirectives]] is still there during the
# rebuild